@@ -6,7 +6,7 @@
 #
 # Parameters:
 # 1: The abbreviated name of sample input and output data files.
-#    E.g. 19 simultaneously means data/19.dot and data/19.lex.
+#    E.g. 19 simultaneously means data/19.gv and data/19.lex.
 # 2 & 3: Use for debugging. Eg -maxlevel debug.
 
-scripts/lex.sh csv data/$1.dot data/$1.lex $2 $3
+scripts/lex.sh csv data/$1.gv data/$1.lex $2 $3
